@@ -80,7 +80,6 @@ class LVMTemplateForm(NetBoxModelForm):
                 "mountpoint",
                 "fs_type",
                 "fs_options",
-                "checkbox_partition"
             ),
         ),
     )
@@ -101,8 +100,27 @@ class LVMTemplateForm(NetBoxModelForm):
         print(f"Filesystem: {self.cleaned_data['fs_type']}")
         print(f"Filesystem Options: {self.cleaned_data['fs_options']}")
         print(f"Checkbox Partition: {self.cleaned_data['checkbox_partition']}")
-        self.instance.vg = self.cleaned_data['drive']
+
+        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
+        device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
+        print(f"Partition Count: {new_partition_count}")
+        print(f"Device Name: {device_name_prefix}")
+        device_name = device_name_prefix + str(new_partition_count)
+        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mount_point'],
+                                                      fs_type=self.cleaned_data['fs_type'],
+                                                      options=self.cleaned_data['fs_options'])
+
+        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
+        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['drive'], type='Linux LVM')
+
+        volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
+        PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
+
+        # Add linux_device for lvm
+        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home', type=self.cleaned_data['fs_type'])
+        self.instance.vg = volume_group
         self.instance.size = self.cleaned_data['size']
+        self.instance.device = linux_device_mapper
         logical_volume = super().save(*args, **kwargs)
 
         return logical_volume
