@@ -24,6 +24,19 @@ drive_menu_item = PluginMenuItem(
     ),
 )
 
+lv_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:logicalvolume_list",
+    link_text="Drives",
+)
+vg_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:volumegroup_list",
+    link_text="Drives",
+)
+pv_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:physicalvolume_list",
+    link_text="Drives",
+)
+
 filesystem_menu_item = PluginMenuItem(
     link="plugins:netbox_storage:filesystem_list",
     link_text="Filesystem",
@@ -106,6 +119,14 @@ menu = PluginMenu(
                 mounted_volume_menu_item,
             ),
         ),
+        (
+            "LVM Configuration",
+            (
+                lv_menu_item,
+                vg_menu_item,
+                pv_menu_item
+            ),
+        ),
         (
             "Storage Configuration",
             (
