@@ -1,9 +1,6 @@
-import django_tables2 as tables
-
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
-    ActionsColumn,
 )
 
 from netbox_storage.models import LogicalVolume
@@ -13,18 +10,6 @@ class LogicalVolumeTable(NetBoxTable):
     """Table for displaying LogicalVolume objects."""
 
     pk = ToggleColumn()
-    fs = tables.Column(
-        linkify=True,
-        verbose_name="Filesystem"
-    )
-    vg = tables.Column(
-        linkify=True,
-        verbose_name="Volume Group Name"
-    )
-    lv_name = tables.Column(
-        linkify=True,
-        verbose_name="Logical Volume Name"
-    )
 
     class Meta(NetBoxTable.Meta):
         model = LogicalVolume
@@ -32,14 +17,14 @@ class LogicalVolumeTable(NetBoxTable):
             "pk",
             "vg",
             "lv_name",
-            "path",
-            "fs",
+            "size",
+            "device",
             "description",
         )
         default_columns = (
             "vg",
             "lv_name",
-            "path",
-            "fs",
-            "description"
+            "size",
+            "device",
+            "description",
         )
