@@ -1,5 +1,3 @@
-import django_tables2 as tables
-
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
@@ -9,31 +7,20 @@ from netbox_storage.models import PhysicalVolume
 
 
 class PhysicalVolumeTable(NetBoxTable):
-    """Table for displaying PhysicalVolume objects."""
+    """Table for displaying VolumeGroup objects."""
 
     pk = ToggleColumn()
-    partition = tables.Column(
-        linkify=True
-    )
-    pv_name = tables.Column(
-        linkify=True
-    )
-    description = tables.Column(
-        linkify=True
-    )
 
     class Meta(NetBoxTable.Meta):
         model = PhysicalVolume
         fields = (
             "pk",
-            "partition",
-            "pv_name",
+            "device",
+            "vg",
             "description",
         )
         default_columns = (
-            "pk",
-            "partition",
-            "pv_name",
+            "device",
+            "vg",
             "description",
         )
-
